
.. _l-HISTORY:

=======
History
=======

current - 2021-11-11 - 0.00Mb
=============================

* #70: Add onnxruntime_training and its extension (2021-11-11)

1.4.1936 - 2021-10-12 - 1.98Mb
==============================

* #69: Fixes for pip==21.3. (2021-10-12)

1.4.1870 - 2021-01-01 - 1.98Mb
==============================

* #68: Exception HTTPTooManyRequests when checking package versions (2020-08-29)
* #67: filter out some warnings when installing a package (2020-04-25)
* #66: remove smopy, not maintained anymore (2019-06-05)
* #65: upgrade dependencies to pip >=10 (2019-03-17)
* #63: add ONNX modules (2019-02-02)
* #60: standalone installation on linux (2019-02-02)
* #62: simplify sets of modules to install (2018-11-10)
* #61: fix import issue for pip 0.18.1 (2018-10-06)
* #33: add code to remove unneeded packages such as gdata (2018-07-31)
* #59: install pythonnet from wheel and not from pip (2018-07-27)
* #58: fix issue with pylzma on Python 3.7 (2018-07-24)
* #56: fix bug in c:\Python37-x64\lib\site-packages\win32ctypes\core\cffi\_advapi32.py (2018-07-23)
* #55: move circleci to python 3.7 (2018-07-23)
* #54: remove basemap (deprecated) (2018-07-22)
* #53: remove arctic, bitarray (2018-07-06)
* #52: remove fastcluster (2018-07-06)
* #51: fix issue with torch (2018-07-06)
* #50: rename climate into climate_toolbox (2018-07-06)
* #49: remove blaze, odo, not maintained (2018-07-06)
* #48: add missing modules for keras (2018-07-06)
* #47: add traceback2 (2018-07-06)
* #46: add pyecharts (2018-07-06)
* #45: filter out warnings added by pip 10 (2018-06-16)
* #44: rename tensorboard (2018-05-02)
* #43: fix param - no longer require C compilation (2018-05-02)
* #42: add options --no-warn-script-location by default for pip >= 10.0 (2018-04-19)
* #41: update for pip 10 (2018-04-14)
* #40: add module absl-py (tensorflow), backcall (ipython) (2018-04-03)
* #39: add ipyscales (2018-03-31)
* #38: add module asteval (lmfit), ipydatawidgets (pythreejs) (2018-03-31)
* #37: add module packaging (2018-03-30)
* #35: add python to PATH when testing datascientist distribution (2018-01-05)
* #34: enable pip+git (2017-09-24)
* #21: fix ete3 (2017-09-17)
* #32: add Python 3.6.2 (2017-09-16)
* #22: fix pypdf and branch trunk (2017-08-29)
* #30: compile dlib for python 3.6 (2017-08-05)
* #27: fix guidata (2017-08-05)
* #29: build dlib on Windows (2017-07-19)
* #20: refresh pystruct, polylearn, dlib, pythonnet (2017-03-22)
* #19: add a test to check the installation of a portable version with many modules (2017-03-16)
* #18: compile fastcache (2017-03-16)
* #13: add tensorflow (if it compiles on Windows) (2017-02-25)
* #16: add blog about rpy2 issue (2016-08-25)
* #14: wheel for module param (2016-08-25)
* #11: switch to https to communicate with pypi (2016-06-18)
* #10: switch from http to https to communicate with pypi (2016-06-18)
